@@ -725,4 +725,4 @@ class Alphafold2(nn.Module):
                 x, coords = self.structure_module(x, coords, mask = mask)
 
         coords.type(original_dtype)
-        return coords
+        return coords, mask
